# linuk
Python Utility library for built in python codes.

# Installation
    
    pip install linuk


# Example
    
    from linuk.basic import listmaker
    listmaker('ab cd ef gh')

# Whats New
New module with python code templates
	import linuk.templates

added acronym_maker to linuk.basic
	from linuk.basic import *
	acronym_maker("Sega Nintendo Sony")
    
## for more documentation use built in help() command.
    
    
